searchData={"items":[{"type":"module","title":"HyperLLM.Chat","doc":"HyperLLM.Chat is a single interface for interacting with LLM providers.\nThe interface uses the OpenAI chat completion API. https://platform.openai.com/docs/api-reference/chat","ref":"HyperLLM.Chat.html"},{"type":"function","title":"HyperLLM.Chat.completion/3","doc":"","ref":"HyperLLM.Chat.html#completion/3"},{"type":"function","title":"Example - HyperLLM.Chat.completion/3","doc":"iex> HyperLLM.Chat.completion(\"openai/gpt-4o-mini\", [%{role: :user, content: \"Hello\"}], [])\n    {:ok, %{\n      \"id\": \"chatcmpl-123\",\n      \"object\": \"chat.completion\",\n      \"created\": 1677652288,\n      \"model\": \"gpt-4o-mini\",\n      \"system_fingerprint\": \"fp_44709d6fcb\",\n      \"choices\": [{\n        \"index\": 0,\n        \"message\": {\n          \"role\": \"assistant\",\n          \"content\": \"Hello there, how may I assist you today?\",\n        },\n        \"logprobs\": null,\n        \"finish_reason\": \"stop\"\n      }],\n      \"service_tier\": \"default\",\n      \"usage\": {\n        \"prompt_tokens\": 9,\n        \"completion_tokens\": 12,\n        \"total_tokens\": 21,\n        \"completion_tokens_details\": {\n          \"reasoning_tokens\": 0,\n          \"accepted_prediction_tokens\": 0,\n          \"rejected_prediction_tokens\": 0\n        }\n      }\n    }}","ref":"HyperLLM.Chat.html#completion/3-example"},{"type":"module","title":"HyperLLM.Conversation","doc":"HyperLLM.Conversation handles the lifecycle of a conversation, including starting, appending messages, and running the conversation.","ref":"HyperLLM.Conversation.html"},{"type":"module","title":"Example - HyperLLM.Conversation","doc":"A Liveview that sends messages to the chat and updates the chat with the response.\n\n    defmodule ChatLive do\n      use Phoenix.LiveView\n\n      def mount(params, session, socket) do\n        {:ok,\n        socket\n        |> assign(conv: HyperLLM.Conversation.start(model: \"openai/gpt-4o-mini\"))}\n      end\n\n      def handle_event(\"send_message\", %{\"message\" => message}, socket) do\n        conv = HyperLLM.Conversation.append(socket.assigns.conv, message)\n\n        send(self(), :chat_completion)\n\n        {:noreply, socket |> assign(conv: conv)}\n      end\n\n      def handle_info(:chat_completion, socket) do\n        with {:ok, conv} <- HyperLLM.Conversation.run(socket.assigns.conv) do\n          {:noreply, socket |> assign(conv: conv)}\n        end\n      end\n    end","ref":"HyperLLM.Conversation.html#module-example"},{"type":"function","title":"HyperLLM.Conversation.append/2","doc":"","ref":"HyperLLM.Conversation.html#append/2"},{"type":"function","title":"HyperLLM.Conversation.append/3","doc":"Append a message to the conversation.","ref":"HyperLLM.Conversation.html#append/3"},{"type":"function","title":"Example - HyperLLM.Conversation.append/3","doc":"iex> HyperLLM.Conversation.start(model: \"openai/gpt-4o-mini\") |> HyperLLM.Conversation.append(:user, \"Hello\")\n    %HyperLLM.Conversation{\n      thread: [%{role: :user, content: \"Hello\"}],\n      model: %HyperLLM.Model{\n        provider: HyperLLM.Provider.OpenAI,\n        model: \"gpt-4o-mini\",\n        config: []\n      }\n    }","ref":"HyperLLM.Conversation.html#append/3-example"},{"type":"type","title":"HyperLLM.Conversation.model_config/0","doc":"","ref":"HyperLLM.Conversation.html#t:model_config/0"},{"type":"function","title":"HyperLLM.Conversation.run/1","doc":"Run the conversation to get a response.","ref":"HyperLLM.Conversation.html#run/1"},{"type":"function","title":"Example - HyperLLM.Conversation.run/1","doc":"iex> HyperLLM.Conversation.start(model: \"openai/gpt-4o-mini\") |> HyperLLM.Conversation.append(:user, \"Hello\") |> HyperLLM.Conversation.run()\n    {:ok, %HyperLLM.Conversation{\n      thread: [%{role: :user, content: \"Hello\"}, %{role: :assistant, content: \"Hello, how can I help you today?\"}],\n      model: \"gpt-4o-mini\"\n    }}","ref":"HyperLLM.Conversation.html#run/1-example"},{"type":"function","title":"HyperLLM.Conversation.run!/1","doc":"","ref":"HyperLLM.Conversation.html#run!/1"},{"type":"function","title":"HyperLLM.Conversation.start/1","doc":"Start a new conversation.","ref":"HyperLLM.Conversation.html#start/1"},{"type":"function","title":"Examples - HyperLLM.Conversation.start/1","doc":"iex> HyperLLM.Conversation.start(model: \"openai/gpt-4o-mini\")\n    %HyperLLM.Conversation{\n      thread: [],\n      model: %HyperLLM.Model{\n        provider: HyperLLM.Provider.OpenAI,\n        model: \"gpt-4o-mini\",\n        config: []\n      }\n    }","ref":"HyperLLM.Conversation.html#start/1-examples"},{"type":"type","title":"HyperLLM.Conversation.t/0","doc":"","ref":"HyperLLM.Conversation.html#t:t/0"},{"type":"module","title":"HyperLLM.Model","doc":"Determine the provider and model for a given model name.","ref":"HyperLLM.Model.html"},{"type":"type","title":"HyperLLM.Model.config/0","doc":"","ref":"HyperLLM.Model.html#t:config/0"},{"type":"function","title":"HyperLLM.Model.list_providers/0","doc":"List all registered provider modules.\n\nExample:\n\n    iex> HyperLLM.Model.list_providers()\n    [\"anthropic\", \"cloudflare\", \"groq\", \"llama_cpp\", \"mistral\", \"ollama\", \"openai\", \"x_ai\"]","ref":"HyperLLM.Model.html#list_providers/0"},{"type":"function","title":"HyperLLM.Model.new!/1","doc":"","ref":"HyperLLM.Model.html#new!/1"},{"type":"function","title":"HyperLLM.Model.parse_model/1","doc":"Parse a model string into a provider and model.\n\nExample:\n\n    iex> HyperLLM.Model.parse_model(\"openai/gpt-4o-mini\")\n    {:ok, {HyperLLM.Provider.OpenAI, \"gpt-4o-mini\"}}\n\n    iex> HyperLLM.Model.parse_model(\"anthropic/claude-3-5-sonnet-20240620\")\n    {:ok, {HyperLLM.Provider.Anthropic, \"claude-3-5-sonnet-20240620\"}}","ref":"HyperLLM.Model.html#parse_model/1"},{"type":"type","title":"HyperLLM.Model.t/0","doc":"","ref":"HyperLLM.Model.html#t:t/0"},{"type":"behaviour","title":"HyperLLM.Tool","doc":"Defines the behaviour that all workflow tool modules must implement.\n\nEach tool module must implement the `call/1` callback, which takes a keyword list\nof inputs and returns a tuple containing a result atom and output keyword list.","ref":"HyperLLM.Tool.html"},{"type":"callback","title":"HyperLLM.Tool.call/1","doc":"Executes the tool with the given input values.","ref":"HyperLLM.Tool.html#c:call/1"},{"type":"callback","title":"Parameters - HyperLLM.Tool.call/1","doc":"* `input` - A keyword list containing the tool-specific input values","ref":"HyperLLM.Tool.html#c:call/1-parameters"},{"type":"callback","title":"Returns - HyperLLM.Tool.call/1","doc":"* `{result, output}` - A tuple containing:\n    * `result` - An atom indicating the result of the tool execution (e.g., :ok, :error, :high, :low)\n    * `output` - A keyword list containing the tool's output values","ref":"HyperLLM.Tool.html#c:call/1-returns"},{"type":"behaviour","title":"HyperLLM.Provider","doc":"Defines the behaviour that all provider modules must implement.","ref":"HyperLLM.Provider.html"},{"type":"callback","title":"HyperLLM.Provider.completion/2","doc":"","ref":"HyperLLM.Provider.html#c:completion/2"},{"type":"type","title":"HyperLLM.Provider.completion_config/0","doc":"","ref":"HyperLLM.Provider.html#t:completion_config/0"},{"type":"type","title":"HyperLLM.Provider.completion_params/0","doc":"","ref":"HyperLLM.Provider.html#t:completion_params/0"},{"type":"callback","title":"HyperLLM.Provider.model_supported?/1","doc":"","ref":"HyperLLM.Provider.html#c:model_supported?/1"},{"type":"function","title":"HyperLLM.Provider.rename_key/3","doc":"","ref":"HyperLLM.Provider.html#rename_key/3"},{"type":"function","title":"HyperLLM.Provider.rename_key/4","doc":"","ref":"HyperLLM.Provider.html#rename_key/4"},{"type":"module","title":"HyperLLM.Provider.Anthropic","doc":"Provider implementation for Anthropic.\n\nhttps://docs.anthropic.com/en/api/messages","ref":"HyperLLM.Provider.Anthropic.html"},{"type":"module","title":"Configuration - HyperLLM.Provider.Anthropic","doc":"`api_key` - The API key for the Anthropic API.\n\n`api_version` - The API version to use. Defaults to `2023-06-01`.\n\n    congfig :hyper_llm, \n      anthropic: [\n        api_key: \"sk-...\",\n        api_version: \"2023-06-01\"\n      ]","ref":"HyperLLM.Provider.Anthropic.html#module-configuration"},{"type":"function","title":"HyperLLM.Provider.Anthropic.completion/2","doc":"See `HyperLLM.Chat.completion/3` for more information.","ref":"HyperLLM.Provider.Anthropic.html#completion/2"},{"type":"function","title":"HyperLLM.Provider.Anthropic.model_supported?/1","doc":"Check if a model is supported by the provider.\n\nSupported Models:\n* claude-3-7-sonnet-latest\n* claude-3-7-sonnet-20250219\n* claude-3-5-sonnet-latest\n* claude-3-5-sonnet-20240620\n* claude-3-5-haiku-latest\n* claude-3-5-haiku-20241022\n* claude-3-opus-20240229\n* claude-3-sonnet-20240229\n* claude-3-haiku-20240307","ref":"HyperLLM.Provider.Anthropic.html#model_supported?/1"},{"type":"module","title":"HyperLLM.Provider.Anthropic.OpenAICompatibility","doc":"This module is used to convert OpenAI requests to Anthropic requests and vice versa.","ref":"HyperLLM.Provider.Anthropic.OpenAICompatibility.html"},{"type":"function","title":"HyperLLM.Provider.Anthropic.OpenAICompatibility.attach/2","doc":"","ref":"HyperLLM.Provider.Anthropic.OpenAICompatibility.html#attach/2"},{"type":"function","title":"HyperLLM.Provider.Anthropic.OpenAICompatibility.from_openai_request/1","doc":"","ref":"HyperLLM.Provider.Anthropic.OpenAICompatibility.html#from_openai_request/1"},{"type":"function","title":"HyperLLM.Provider.Anthropic.OpenAICompatibility.to_openai_chat_completion_response/1","doc":"","ref":"HyperLLM.Provider.Anthropic.OpenAICompatibility.html#to_openai_chat_completion_response/1"},{"type":"function","title":"HyperLLM.Provider.Anthropic.OpenAICompatibility.to_openai_chat_completion_streaming_response/1","doc":"","ref":"HyperLLM.Provider.Anthropic.OpenAICompatibility.html#to_openai_chat_completion_streaming_response/1"},{"type":"module","title":"HyperLLM.Provider.Cloudflare","doc":"Provider implementation for Cloudflare.\n\nUses Cloudflare's [OpenAI compatibility API](https://developers.cloudflare.com/workers-ai/configuration/open-ai-compatibility/) for chat completions.","ref":"HyperLLM.Provider.Cloudflare.html"},{"type":"module","title":"Configuration - HyperLLM.Provider.Cloudflare","doc":"`api_key` - The API key for the Cloudflare API.\n\n`account_id` - The account ID for the Cloudflare API.\n\n    congfig :hyper_llm, \n      cloudflare: [\n        api_key: \"sk-...\",\n        account_id: \"...\"\n      ]","ref":"HyperLLM.Provider.Cloudflare.html#module-configuration"},{"type":"function","title":"HyperLLM.Provider.Cloudflare.completion/2","doc":"See `HyperLLM.Chat.completion/3` for more information.","ref":"HyperLLM.Provider.Cloudflare.html#completion/2"},{"type":"function","title":"HyperLLM.Provider.Cloudflare.model_supported?/1","doc":"Checks if the model starts with `@`","ref":"HyperLLM.Provider.Cloudflare.html#model_supported?/1"},{"type":"module","title":"HyperLLM.Provider.Groq","doc":"Groq provider.\n\nhttps://console.groq.com/docs/api-reference","ref":"HyperLLM.Provider.Groq.html"},{"type":"module","title":"Configuration - HyperLLM.Provider.Groq","doc":"`api_key` - The API key for the Groq API.\n\n    congfig :hyper_llm, \n      groq: [\n        api_key: \"sk-...\",\n      ]","ref":"HyperLLM.Provider.Groq.html#module-configuration"},{"type":"function","title":"HyperLLM.Provider.Groq.completion/2","doc":"See `HyperLLM.Chat.completion/3` for more information.","ref":"HyperLLM.Provider.Groq.html#completion/2"},{"type":"function","title":"HyperLLM.Provider.Groq.model_supported?/1","doc":"Check if a model is supported by the provider.\n\nSupported Models:\n* deepseek-r1-distill-llama-70b\n* distil-whisper-large-v3-en\n* gemma2-9b-it\n* llama-3.1-8b-instant\n* llama-3.2-11b-vision-preview\n* llama-3.2-1b-preview\n* llama-3.2-90b-vision-preview\n* llama-3.2-3b-preview\n* llama-3.3-70b-specdec\n* llama-3.3-70b-versatile\n* llama-guard-3-8b\n* llama3-70b-8192\n* llama3-8b-8192\n* mixtral-8x7b-32768\n* whisper-large-v3-turbo\n* whisper-large-v3","ref":"HyperLLM.Provider.Groq.html#model_supported?/1"},{"type":"module","title":"HyperLLM.Provider.LlamaCPP","doc":"Provider implementation for LlamaCPP.\n\nLlamaCPP server that implements the OpenAI API format.\nhttps://github.com/ggerganov/llama.cpp/tree/master/examples/server","ref":"HyperLLM.Provider.LlamaCPP.html"},{"type":"module","title":"Configuration - HyperLLM.Provider.LlamaCPP","doc":"`api_key` - The API key for the LlamaCPP API (optional).\n`base_url` - The base URL for the LlamaCPP API.\n\n    config :hyper_llm, \n      llama_cpp: [\n        api_key: \"llamacpp\",\n        base_url: \"http://localhost:8080\"\n      ]","ref":"HyperLLM.Provider.LlamaCPP.html#module-configuration"},{"type":"function","title":"HyperLLM.Provider.LlamaCPP.completion/2","doc":"See `HyperLLM.Chat.completion/3` for more information.","ref":"HyperLLM.Provider.LlamaCPP.html#completion/2"},{"type":"function","title":"HyperLLM.Provider.LlamaCPP.model_supported?/1","doc":"Check if a model is supported by the provider.\n\nAll models are supported as they are loaded into the server directly.","ref":"HyperLLM.Provider.LlamaCPP.html#model_supported?/1"},{"type":"module","title":"HyperLLM.Provider.Mistral","doc":"Provider implementation for Mistral.ai.\n\nhttps://docs.mistral.ai/api/","ref":"HyperLLM.Provider.Mistral.html"},{"type":"module","title":"Configuration - HyperLLM.Provider.Mistral","doc":"`api_key` - The API key for the Mistral API.\n\n    config :hyper_llm, \n      mistral: [\n        api_key: \"...\",\n      ]","ref":"HyperLLM.Provider.Mistral.html#module-configuration"},{"type":"function","title":"HyperLLM.Provider.Mistral.completion/2","doc":"See `HyperLLM.Chat.completion/3` for more information.","ref":"HyperLLM.Provider.Mistral.html#completion/2"},{"type":"function","title":"HyperLLM.Provider.Mistral.model_supported?/1","doc":"Check if a model is supported by the provider.\n\nSupported Models:\n* codestral-latest\n* mistral-large-latest\n* pixtral-large-latest\n* mistral-3b-latest\n* mistral-8b-latest\n* mistral-embed\n* mistral-moderation-latest\n* mistral-small-latest\n* pixtral-12b-2409\n* open-mistral-nemo\n* open-codestral-mamba","ref":"HyperLLM.Provider.Mistral.html#model_supported?/1"},{"type":"module","title":"HyperLLM.Provider.Ollama","doc":"Provider implementation for Ollama.\n\nhttps://github.com/ollama/ollama/blob/main/docs/api.md#generate-a-chat-completion","ref":"HyperLLM.Provider.Ollama.html"},{"type":"module","title":"Configuration - HyperLLM.Provider.Ollama","doc":"`api_url` - The URL for the Ollama API. Defaults to `http://localhost:11434`.\n\n`api_key` - The API key for the Ollama API.  Defaults to `ollama`.\n\n    config :hyper_llm, \n      ollama: [\n        api_url: \"http://localhost:11434\",\n        api_key: \"ollama\"\n      ]","ref":"HyperLLM.Provider.Ollama.html#module-configuration"},{"type":"function","title":"HyperLLM.Provider.Ollama.completion/2","doc":"See `HyperLLM.Chat.completion/3` for more information.","ref":"HyperLLM.Provider.Ollama.html#completion/2"},{"type":"function","title":"HyperLLM.Provider.Ollama.model_supported?/1","doc":"Ollama supports all models.","ref":"HyperLLM.Provider.Ollama.html#model_supported?/1"},{"type":"module","title":"HyperLLM.Provider.OpenAI","doc":"Provider implementation for OpenAI.\n\nhttps://platform.openai.com/docs/api-reference/chat","ref":"HyperLLM.Provider.OpenAI.html"},{"type":"module","title":"Configuration - HyperLLM.Provider.OpenAI","doc":"`api_key` - The API key for the OpenAI API.\n\n    congfig :hyper_llm, \n      openai: [\n        api_key: \"sk-...\"\n      ]","ref":"HyperLLM.Provider.OpenAI.html#module-configuration"},{"type":"function","title":"HyperLLM.Provider.OpenAI.completion/2","doc":"See `HyperLLM.Chat.completion/3` for more information.","ref":"HyperLLM.Provider.OpenAI.html#completion/2"},{"type":"function","title":"HyperLLM.Provider.OpenAI.model_supported?/1","doc":"Check if a model is supported by the provider.\n\nSupported Models:\n* gpt-3.5-turbo\n* gpt-3.5-turbo-0125\n* gpt-3.5-turbo-1106\n* gpt-3.5-turbo-instruct\n* gpt-4-turbo\n* gpt-4-turbo-2024-04-09\n* gpt-4-turbo-preview\n* gpt-4-0125-preview\n* gpt-4-1106-preview\n* gpt-4\n* gpt-4-0613\n* gpt-4-0314\n* gpt-4o-2024-11-20\n* gpt-4o-2024-08-06\n* gpt-4o-2024-05-13\n* gpt-4o-mini\n* gpt-4o-mini-2024-07-18\n* o1\n* o1-2024-12-17\n* o1-mini\n* o1-mini-2024-09-12\n* o1-preview\n* o1-preview-2024-09-12\n* o3-mini\n* o3-mini-2025-01-31","ref":"HyperLLM.Provider.OpenAI.html#model_supported?/1"},{"type":"module","title":"HyperLLM.Provider.XAI","doc":"Provider implementation for X.ai.\n\nAPI Reference: [X.ai API Reference](https://docs.x.ai/docs/api-reference)","ref":"HyperLLM.Provider.XAI.html"},{"type":"module","title":"Configuration - HyperLLM.Provider.XAI","doc":"config :hyper_llm,\n      x_ai: [\n        api_url: \"https://api.x.ai/v1\",\n        api_key: \"YOUR_API_KEY\"\n      ]","ref":"HyperLLM.Provider.XAI.html#module-configuration"},{"type":"function","title":"HyperLLM.Provider.XAI.completion/2","doc":"See `HyperLLM.Chat.completion/3` for more information.","ref":"HyperLLM.Provider.XAI.html#completion/2"},{"type":"function","title":"HyperLLM.Provider.XAI.model_supported?/1","doc":"Check if a model is supported by the provider.\n\nSupported Models:\n* grok-vision-beta\n* grok-2-vision-1212\n* grok-2-vision\n* grok-2-vision-latest\n* grok-2-1212\n* grok-2\n* grok-2-latest\n* grok-beta","ref":"HyperLLM.Provider.XAI.html#model_supported?/1"},{"type":"extras","title":"HyperLLM","doc":"# HyperLLM\n\n[![CI](https://github.com/cgarvis/hyper_llm/actions/workflows/elixir.yml/badge.svg)](https://github.com/cgarvis/hyper_llm/actions/workflows/elixir.yml)\n[![License](https://img.shields.io/hexpm/l/hyper_llm.svg)](https://github.com/cgarvis/hyper_llm/blob/main/LICENSE.md)\n[![Version](https://img.shields.io/hexpm/v/hyper_llm.svg)](https://hex.pm/packages/hyper_llm)\n[![Hex Docs](https://img.shields.io/badge/documentation-gray.svg)](https://hexdocs.pm/hyper_llm)\n\nCall all LLM APIs using the OpenAI format.","ref":"readme.html"},{"type":"extras","title":"Installation - HyperLLM","doc":"Add `hyper_llm` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:hyper_llm, \"~> 0.6.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configurations - HyperLLM","doc":"```elixir\nconfig :hyper_llm,\n  openai: [\n    api_key: \"sk-...\"\n  ],\n  anthropic: [\n    api_key: \"sk-...\"\n  ],\n  # ...\n```","ref":"readme.html#configurations"},{"type":"extras","title":"Usage - HyperLLM","doc":"The `HyperLLM.Conversation` module is used to start a new conversation of the LLM provider of your choices.\n\n```elixir\nHyperLLM.Conversation.start(model: \"openai/gpt-4o-mini\")\n|> HyperLLM.Conversation.append(:developer, \"You are a helpful assistant.\")\n|> HyperLLM.Conversation.append(\"Spell strawbeerry\")\n|> HyperLLM.Conversation.run!()\n#=> %HyperLLM.Conversation{\n  model: \"openai/gpt-4o-mini\",\n  thread: [\n    %{role: \"developer\", content: \"You are a helpful assistant.\"},\n    %{role: \"user\", content: \"Spell strawbeerry\"},\n    %{role: \"assistant\", content: \"Strawberry. 🍓\"}\n  ]\n}\n```\n\nUnder the hood, the `HyperLLM.Conversation` module is using `HyperLLM.Chat.completion/3` to receive a OpenAI compatible response.\n\n```elixir\nHyperLLM.Chat.completion(\"openai/gpt-4o-mini\", [\n  %{role: \"user\", content: \"Spell \\\"strawberry\\\"\"}\n])\n#=> {:ok, %{\n  \"id\" => \"chatcmpl-1234567890\",\n  \"object\" => \"chat.completion\",\n  \"created\" => 1717753987,\n  \"choices\" => [\n    %{\n      \"message\" => %{\n        \"role\" => \"assistant\",\n        \"content\" => \"Strawberry. 🍓\"\n      },\n      \"index\" => 0,\n      \"finish_reason\" => \"stop\"\n    }\n  ]\n}}\n```\n\n```elixir\nHyperLLM.Chat.completion(\"anthropic/claude-3-5-sonnet-20240620\", [\n  %{role: \"user\", content: \"Spell \\\"strawberry\\\"\"}\n])\n#=> {:ok, %{\n  \"id\" => \"chatcmpl-1234567890\",\n  \"object\" => \"chat.completion\",\n  \"created\" => 1717753987,\n  \"choices\" => [\n    %{\n      \"message\" => %{\n        \"role\" => \"assistant\",\n        \"content\" => \"Strawberry. 🍓\"\n      },\n      \"index\" => 0,\n      \"finish_reason\" => \"stop\"\n    }\n  ]\n}}\n```\n\nIf you are using Phoenix, you can use the `HyperLLM.Conversation` module in your LiveView.\n\n```elixir\ndefmodule ChatLive do\n  use Phoenix.LiveView\n\n  def render(assigns) do\n    ~H\"\"\"\n     \n       \n        <%= for message <- @chat.messages do %>\n           <%= message.role %> \n           <%= message.content %> \n        <% end %>\n       \n     \n    \"\"\"\n  end\n\n  def mount(params, session, socket) do\n    {:ok,\n    socket\n    |> assign(conv: HyperLLM.Conversation.start(model: \"openai/gpt-4o-mini\"))}\n  end\n\n  def handle_event(\"send_message\", %{\"message\" => message}, socket) do\n    conv = HyperLLM.Conversation.append(socket.assigns.conv, :user, message)\n\n    send(self(), :chat_completion)\n    \n    {:noreply, socket |> assign(conv: conv)}\n  end\n\n  def handle_info(:chat_completion, socket) do\n    with {:ok, conv} <- HyperLLM.Conversation.run(socket.assigns.conv) do\n      {:noreply, socket |> assign(conv: conv)}\n    end\n  end\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Provider Support - HyperLLM","doc":"| Provider           | Completion | Streaming | \n| ------------------ | ---------- | --------- |\n| Anthropic          | ✅         | ❌        |\n| Cloudflare         | ✅         | ❌        |\n| Groq               | ✅         | ❌        |\n| LlamaCPP           | ✅         | ❌        |\n| Mistral            | ✅         | ❌        |\n| Ollama             | ✅         | ❌        |\n| OpenAI             | ✅         | ❌        |\n| xAI                | ✅         | ❌        |\n| Azure              | ❌         | ❌        |\n| AWS SageMaker      | ❌         | ❌        |\n| AWS Bedrock        | ❌         | ❌        |\n| Cohere             | ❌         | ❌        |\n| DeepSeek           | ❌         | ❌        |\n| Empower            | ❌         | ❌        |\n| Google - Vertex AI | ❌         | ❌        |\n| Google - Palm      | ❌         | ❌        |\n| Google AI Studio   | ❌         | ❌        |\n| Hugging Face       | ❌         | ❌        |\n| Perplexity         | ❌         | ❌        |\n| Replicate          | ❌         | ❌        |\n| TogetherAI         | ❌         | ❌        |\n| Vertex AI          | ❌         | ❌        |","ref":"readme.html#provider-support"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}